==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_mua.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_mua extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Solai Arabiya" },
            { "aoa", "solai Angola" },
            { "aud", "solai Australya" },
            { "bhd", "solai Barenya" },
            { "bif", "solai Burundi" },
            { "bwp", "solai Botswana" },
            { "cad", "solai Kanada" },
            { "cdf", "solai Kongo" },
            { "chf", "Solai Swiss" },
            { "cny", "solai Syi\u014b" },
            { "cve", "solai Kapverdiya" },
            { "djf", "solai Djibouti" },
            { "dzd", "solai Algerya" },
            { "egp", "solai Egypt" },
            { "ern", "solai Eritre" },
            { "etb", "solai Etiopia" },
            { "eur", "solai Euro" },
            { "gbp", "solai Britaniya" },
            { "ghc", "solai Gana" },
            { "gmd", "solai Gambiya" },
            { "gns", "solai Guine" },
            { "inr", "solai India" },
            { "jpy", "solai Japo\u014b" },
            { "kes", "solai Kenia" },
            { "kmf", "solai Komorya" },
            { "lrd", "solai Liberiya" },
            { "lsl", "solai Lesotho" },
            { "lyd", "solai Libya" },
            { "mad", "Solai Marok" },
            { "mga", "Solai Malagasya" },
            { "mro", "Solai Mauritaniya (1973\u20132017)" },
            { "mru", "Solai Mauritaniya" },
            { "mur", "Solai Mauric\u01dd" },
            { "mwk", "Solai Malawi" },
            { "mzm", "Solai Mozambika" },
            { "nad", "Solai Namibiya" },
            { "ngn", "Solai Nigeriya" },
            { "rwf", "Solai Rwanda" },
            { "sar", "Solai Saudiya" },
            { "scr", "Solai Saichel" },
            { "sdg", "Solai Suda\u014b ma dii ne dinar" },
            { "sdp", "Solai Suda\u014b ma dii ne livre" },
            { "shp", "Solai Helena" },
            { "sll", "solai Sierra leon\u01dd" },
            { "sos", "Solai Somaliya" },
            { "std", "Solai Sao Tome (1977\u20132017)" },
            { "stn", "Solai Sao Tome" },
            { "szl", "solai Swaziland" },
            { "tnd", "Solai Tunisiya" },
            { "tzs", "Solai Tanzaniya" },
            { "ugx", "Solai Uganda" },
            { "usd", "Solai Amerika" },
            { "xaf", "solai BEAC" },
            { "xof", "solai BCEAO" },
            { "zar", "Solai Africa nek\u01dds\u01dd\u014b" },
            { "zmk", "Solai Zambiya (1968\u20132012)" },
            { "zmw", "Solai Zambiya" },
            { "zwd", "Solai Zimbabwe" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1.1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_mua.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_mua extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "Solai Arabiya" },
            { "aoa", "solai Angola" },
            { "aud", "solai Australya" },
            { "bhd", "solai Barenya" },
            { "bif", "solai Burundi" },
            { "bwp", "solai Botswana" },
            { "cad", "solai Kanada" },
            { "cdf", "solai Kongo" },
            { "chf", "Solai Swiss" },
            { "cny", "solai Syi\u014b" },
            { "cve", "solai Kapverdiya" },
            { "djf", "solai Djibouti" },
            { "dzd", "solai Algerya" },
            { "egp", "solai Egypt" },
            { "ern", "solai Eritre" },
            { "etb", "solai Etiopia" },
            { "eur", "solai Euro" },
            { "gbp", "solai Britaniya" },
            { "ghc", "solai Gana" },
            { "gmd", "solai Gambiya" },
            { "gns", "solai Guine" },
            { "inr", "solai India" },
            { "jpy", "solai Japo\u014b" },
            { "kes", "solai Kenia" },
            { "kmf", "solai Komorya" },
            { "lrd", "solai Liberiya" },
            { "lsl", "solai Lesotho" },
            { "lyd", "solai Libya" },
            { "mad", "Solai Marok" },
            { "mga", "Solai Malagasya" },
            { "mro", "Solai Mauritaniya (1973\u20132017)" },
            { "mru", "Solai Mauritaniya" },
            { "mur", "Solai Mauric\u01dd" },
            { "mwk", "Solai Malawi" },
            { "mzm", "Solai Mozambika" },
            { "nad", "Solai Namibiya" },
            { "ngn", "Solai Nigeriya" },
            { "rwf", "Solai Rwanda" },
            { "sar", "Solai Saudiya" },
            { "scr", "Solai Saichel" },
            { "sdg", "Solai Suda\u014b ma dii ne dinar" },
            { "sdp", "Solai Suda\u014b ma dii ne livre" },
            { "shp", "Solai Helena" },
            { "sle", "solai Sierra leon\u01dd" },
            { "sll", "solai Sierra leon\u01dd (1964\u20142022)" },
            { "sos", "Solai Somaliya" },
            { "std", "Solai Sao Tome (1977\u20132017)" },
            { "stn", "Solai Sao Tome" },
            { "szl", "solai Swaziland" },
            { "tnd", "Solai Tunisiya" },
            { "tzs", "Solai Tanzaniya" },
            { "ugx", "Solai Uganda" },
            { "usd", "Solai Amerika" },
            { "xaf", "solai BEAC" },
            { "xof", "solai BCEAO" },
            { "zar", "Solai Africa nek\u01dds\u01dd\u014b" },
            { "zmk", "Solai Zambiya (1968\u20132012)" },
            { "zmw", "Solai Zambiya" },
            { "zwd", "Solai Zimbabwe" },
        };
        return data;
    }
}
